Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.cpp	(revision 71523)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.cpp	(revision 71524)
@@ -5,5 +5,5 @@
 
 /*
- * Copyright (C) 2011-2017 Oracle Corporation
+ * Copyright (C) 2011-2018 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
@@ -29,12 +29,12 @@
 using namespace UISettingsDefs;
 
-ConfigurationAccessLevel UISettingsDefs::configurationAccessLevel(KSessionState sessionState, KMachineState machineState)
+ConfigurationAccessLevel UISettingsDefs::configurationAccessLevel(KSessionState enmSessionState, KMachineState enmMachineState)
 {
     /* Depending on passed arguments: */
-    switch (machineState)
+    switch (enmMachineState)
     {
         case KMachineState_PoweredOff:
         case KMachineState_Teleported:
-        case KMachineState_Aborted:    return sessionState == KSessionState_Unlocked ?
+        case KMachineState_Aborted:    return enmSessionState == KSessionState_Unlocked ?
                                               ConfigurationAccessLevel_Full :
                                               ConfigurationAccessLevel_Partial_PoweredOff;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.h	(revision 71523)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDefs.h	(revision 71524)
@@ -5,5 +5,5 @@
 
 /*
- * Copyright (C) 2011-2017 Oracle Corporation
+ * Copyright (C) 2011-2018 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
@@ -46,6 +46,7 @@
     };
 
-    /** Determines configuration access level for passed @a sessionState and @a machineState. */
-    ConfigurationAccessLevel configurationAccessLevel(KSessionState sessionState, KMachineState machineState);
+    /** Determines configuration access level for passed @a enmSessionState and @a enmMachineState. */
+    ConfigurationAccessLevel configurationAccessLevel(KSessionState enmSessionState,
+                                                      KMachineState enmMachineState);
 }
 
@@ -122,7 +123,7 @@
     int childCount() const { return m_children.size(); }
     /** Returns the modifiable REFERENCE to the child cached data. */
-    ChildCacheData& child(const QString &strChildKey) { return m_children[strChildKey]; }
+    ChildCacheData &child(const QString &strChildKey) { return m_children[strChildKey]; }
     /** Wraps method above to return the modifiable REFERENCE to the child cached data. */
-    ChildCacheData& child(int iIndex) { return child(indexToKey(iIndex)); }
+    ChildCacheData &child(int iIndex) { return child(indexToKey(iIndex)); }
     /** Returns the NON-modifiable COPY to the child cached data. */
     const ChildCacheData child(const QString &strChildKey) const { return m_children[strChildKey]; }
@@ -281,4 +282,5 @@
 };
 
+
 #endif /* !___UISettingsDefs_h___ */
 
